Uses of Interface org.openqa.selenium.server.browserlaunchers.locators.BrowserLocator (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Interface
org.openqa.selenium.server.browserlaunchers.locators.BrowserLocator

Packages that use BrowserLocator
org.openqa.selenium.server.browserlaunchers | Provides classes to launch and kill browsers.
org.openqa.selenium.server.browserlaunchers.locators |

Uses of BrowserLocator in org.openqa.selenium.server.browserlaunchers

Methods in org.openqa.selenium.server.browserlaunchers with parameters of type BrowserLocator
`BrowserInstallation` | `BrowserInstallationCache.locateBrowserInstallation(java.lang.String browserName, java.lang.String customLauncherPath, BrowserLocator locator)`

Uses of BrowserLocator in org.openqa.selenium.server.browserlaunchers.locators

Classes in org.openqa.selenium.server.browserlaunchers.locators that implement BrowserLocator
`class` | `Firefox2Locator` Discovers a valid Firefox 2.x installation on local system.
`class` | `Firefox2or3Locator` Discovers a valid Firefox installation on local system.
`class` | `Firefox3Locator` Discovers a valid Firefox 2.x or 3.x installation on local system.
`class` | `FirefoxLocator` Discovers a valid Firefox installation on local system.
`class` | `GoogleChromeLocator` Discovers a valid Google Chrome installation on local system.
`class` | `InternetExplorerLocator` Discovers a valid Internet Explorer installation on local system.
`class` | `SafariLocator` Discovers a valid Internet Explorer installation on local system.
`class` | `SingleBrowserLocator` Discovers a valid browser installation on local system.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.